This is unreleased documentation for Yew Next version.
For up-to-date documentation, see the latest version on docs.rs.

Attributes

Enum Attributes 

#[non_exhaustive]
pub enum Attributes { }
A collection of attributes for an element

Implementations

Source

impl Attributes

pub fn from_static( statics: &'static [(&'static str, AttributeOrProperty)], ) -> Self

Static list of attributes.

Allows optimizing comparison to a simple pointer equality check and reducing allocations, if the attributes do not change on a node.

pub fn from_static_unchecked( statics: &'static [(&'static str, AttributeOrProperty)], ) -> Self

Same as Self::from_static but without verifying keys. This can lead to loss of validity of an SSR document!

pub fn from_dynamic_values( keys: &'static [&'static str], values: Box<[Option<AttributeOrProperty>]>, ) -> Self

Static list of attribute keys with possibility to exclude attributes and dynamic attribute values.

Allows optimizing comparison to a simple pointer equality check and reducing allocations, if the attributes keys do not change on a node.

pub fn from_dynamic_values_unchecked( keys: &'static [&'static str], values: Box<[Option<AttributeOrProperty>]>, ) -> Self

Same as Self::from_dynamic_values but without verifying keys. This can lead to loss of validity of an SSR document!

pub fn from_index_map(map: Rc<IndexMap<AttrValue, AttributeOrProperty>>) -> Self

IndexMap is used to provide runtime attribute deduplication in cases where the html! macro was not used to guarantee it.

pub fn from_index_map_unchecked( map: Rc<IndexMap<AttrValue, AttributeOrProperty>>, ) -> Self

Same as Self::from_index_map but without verifying keys. This can lead to loss of validity of an SSR document!

pub fn is_valid_attr_key(name: &str) -> bool

Validate a single attribute name for validity to be used as a key for an attribute or property. All keys must be valid according to this method when constructing Attributes. Usually, this is ensured by the usage context.

Specifically, this checks that the passed string is a valid XHTML attribute name. This implies that it consists of at least one character, does not contain whitespace or other special characters.

pub fn new() -> Self

Construct a default Attributes instance

pub fn iter<'a>(&'a self) -> Box<dyn Iterator<Item = (&'a str, &'a str)> + 'a>

Return iterator over attribute key-value pairs. This function is suboptimal and does not inline well. Avoid on hot paths.

This function only returns attributes

pub fn get_mut_index_map_unchecked( &mut self, ) -> &mut IndexMap<AttrValue, AttributeOrProperty>

Get a mutable reference to the underlying IndexMap. If the attributes are stored in the Vec variant, it will be converted. The caller is responsible to check that inserted attribute names are valid, see Self::is_valid_attr_key